#!/bin/sh
#---------------------------------------------------------------
# Project         : hardware4linux
# Module          : hwreport
# File            : cron.sh
# Version         : $Id$
# Author          : Frederic Lepied
# Created On      : Wed Apr 30 20:52:20 2008
# Purpose         : script that can be run by crontab to periodically
#		upload a report in an anonymous way.  The report will
#		be uploaded only if something has changed.
#---------------------------------------------------------------

print_error() {
    if tty > /dev/null 2>&1; then
	echo "$@" 1>&2
    fi
}

if [ ! -r /etc/sysconfig/hw-uuid -a /proc/sys/kernel/random/uuid ]; then
    cp /proc/sys/kernel/random/uuid /etc/sysconfig/hw-uuid
    chmod og-rwx /etc/sysconfig/hw-uuid
fi

if [ ! -r /etc/sysconfig/hw-uuid ]; then
    print_error "no uuid for this system. exiting."
    exit 1
fi

VARDIR=/var/lib/hwreport
BINDIR=/usr/sbin
URL=http://hardware4linux.info/anon/

PATH=$BINDIR/../lib:$PATH
export PATH

mkdir -p "$VARDIR"
chmod go-rwx "$VARDIR"

$BINDIR/hwreport "$VARDIR/report" > /dev/null 2>&1

new=`ls "$VARDIR/"report.* 2> /dev/null`

if [ ! -r "$new" ]; then
    print_error "unable to generate report. exiting"
    exit 1
fi

mkdir "$VARDIR"/d2
cd "$VARDIR"/d2

case "$new" in
    *.bz2)
	bzcat "$new" | tar x
	;;
    *.gz)
	zcat "$new" | tar x
	;;
    *.zip)
	unzip "$new"
	;;
    *)
	print_error "unknown format"
	exit 1
	;;
esac

# this file contains the date of the collection
# so we need to remove it before comparing with
# the previous run.
rm -f hwreport.info

if [ -d "$VARDIR/d" ]; then
    # check if something has changed
    if diff -rq "$VARDIR/d" "$VARDIR/d2" > /dev/null 2>&1; then
	rm -rf "$VARDIR/d2" "$new"
	exit 0
    fi
fi

if type curl > /dev/null 2>&1; then
    curl -f -F uuid=`cat "$VARDIR/d2/hw-uuid"` -F file=@"$new" $URL
    status=$?
    rm -f "$new"
    if [ $status = 0 ]; then
	rm -rf "$VARDIR/d"
	mv "$VARDIR/d2" "$VARDIR/d"
	exit 0
    else
	print_error "problem uploading. exiting"
    fi
else
    print_error "no wget. exiting"
fi

rm -rf "$VARDIR/d2"
exit 1

# cron.sh ends here
